import { useZoneEditorStore } from '@/stores/zoneEditorStore'
import { computed, watch, type Ref } from 'vue'
import { useGamePointerHandlers } from './pointerHandlers/useGamePointerHandlers'
import { useZoneEditorPointerHandlers } from './pointerHandlers/useZoneEditorPointerHandlers'

export function usePointerHandlers(scene: Phaser.Scene, layer: Phaser.Tilemaps.TilemapLayer, waypoint: Ref<{ visible: boolean; x: number; y: number }>, camera: Phaser.Cameras.Scene2D.Camera) {
  const zoneEditorStore = useZoneEditorStore()
  const gameHandlers = useGamePointerHandlers(scene, layer, waypoint, camera)
  const zoneEditorHandlers = useZoneEditorPointerHandlers(scene, layer, waypoint, camera)

  const currentHandlers = computed(() => (zoneEditorStore.active ? zoneEditorHandlers : gameHandlers))

  const setupPointerHandlers = () => currentHandlers.value.setupPointerHandlers()
  const cleanupPointerHandlers = () => currentHandlers.value.cleanupPointerHandlers()

  watch(
    () => zoneEditorStore.active,
    () => {
      cleanupPointerHandlers()
      setupPointerHandlers()
    }
  )

  return { setupPointerHandlers, cleanupPointerHandlers }
}
